Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1603)

Unified Diff: fetch_configs/crashpad.py

Issue 1494793002: Rename recipes/ to fetch_configs/ (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/tools/depot_tools
Patch Set: Renamed recipes to configs Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « fetch_configs/config_util.py ('k') | fetch_configs/dart.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: fetch_configs/crashpad.py
diff --git a/recipes/crashpad.py b/fetch_configs/crashpad.py
similarity index 81%
rename from recipes/crashpad.py
rename to fetch_configs/crashpad.py
index 7342300bedb9355694e3e3949ffe1161ed4ce196..d50992b3d2dc6ee4b304c4849436688798ad686d 100644
--- a/recipes/crashpad.py
+++ b/fetch_configs/crashpad.py
@@ -4,13 +4,13 @@
import sys
-import recipe_util # pylint: disable=F0401
+import config_util # pylint: disable=F0401
# This class doesn't need an __init__ method, so we disable the warning
# pylint: disable=W0232
-class CrashpadRecipe(recipe_util.Recipe):
- """Basic Recipe class for Crashpad."""
+class CrashpadConfig(config_util.Config):
+ """Basic Config class for Crashpad."""
@staticmethod
def fetch_spec(props):
@@ -34,7 +34,7 @@ class CrashpadRecipe(recipe_util.Recipe):
def main(argv=None):
- return CrashpadRecipe().handle_args(argv)
+ return CrashpadConfig().handle_args(argv)
if __name__ == '__main__':
« no previous file with comments | « fetch_configs/config_util.py ('k') | fetch_configs/dart.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698